//+------------------------------------------------------------------+
//|                                     Real_Time_MultiExpert_v1.mq4 |
//|                                 Copyright  2007, Pavel Chigirev |
//+------------------------------------------------------------------+
#property copyright "Copyright  2007, Pavel Chigirev"
#property link      ""
//----
extern color TColor = SteelBlue;
extern color TxtColor = Red;
//----  
extern string p1 = " SAR";
extern double SAR_Step = 0.01;
extern double SAR_Max = 0.1;
extern string p2 = " MACD";
extern int Fast_EMA = 12;
extern int Slow_EMA = 26;
extern int MACD_SMA = 9;
extern string p3 = " Moving Average";
extern int Fast_MA = 5;
extern int Slow_MA = 10;
extern string p4 = " ADX";
extern int ADX_Period = 14;
//extern string p5 = "  1";
//extern string p6 = "  2";
//extern string p7 = "  3";
//---- 
int t1, t2, t11, t12, t13, t14, t15, a, b;
int textT[6], textC[8], tt[10];
int per[] = {15, 30, 60, 240};
string nameS[] = {"INDICATOR", "M15", "M30", "H1", "H4"};
string name1[] = {"Parabolic SAR", "MACD", "rossing MA", "ADX", "", 
                 "", ""}, name[] = {"", "", "", "", "", "", ""};
//+------------------------------------------------------------------+
//| Initialization                                                   |
//+------------------------------------------------------------------+
int init()
  {
   name[0] = name1[0] + "(" + DoubleToStr(SAR_Step, 2) + ", " + 
             DoubleToStr(SAR_Max, 2) + ")";
   name[1] = name1[1] + "(" + DoubleToStr(Fast_EMA, 0) + ", " + 
             DoubleToStr(Slow_EMA, 0) + ", " + 
             DoubleToStr(MACD_SMA, 0) + ")";
   name[2] = name1[2] + "(" + DoubleToStr(Fast_MA, 0) + ", " + 
             DoubleToStr(Slow_MA, 0) + ")";
   name[3] = name1[3] + "(" + DoubleToStr(ADX_Period, 0) + ")";
//   name[4] = name[4] + "(" + DoubleToStr(1-   1,0) + 
//             ", " + DoubleToStr(2-   1, 0) + ")";
//   name[5] = name[5] + "(" + DoubleToStr(1-   2,0) + 
//             ", " + DoubleToStr(2-   2,0)+")";
//   name[6] = name[6] + "(" + DoubleToStr(1-   3,0) + 
//             ", " + DoubleToStr(2-   3,0)+")";
   return(0);
  }
//+------------------------------------------------------------------+
//| Check errors                                                     |
//+------------------------------------------------------------------+
int Error(int p, int a)
  {
    double s = iClose(NULL, p, a);
    if(s == 0) 
        return(1);
  }
//+------------------------------------------------------------------+
//| Parabolic SAR                                                    |
//+------------------------------------------------------------------+
string SAR(int p)
  {
   int ii = 1;
   if(iSAR(NULL, p, SAR_Step, SAR_Max, 0) > iClose(NULL, p, ii)) 
     {
       while(iSAR(NULL, p, SAR_Step, SAR_Max, ii) > iClose(NULL, p, ii))
           ii++;
       if(Error(p, ii + 1) == 1) 
           return("Absent data");
       return("Sell(" + DoubleToStr(ii, 0) + ")");
     }
   else 
     {
       while(iSAR(NULL, p, SAR_Step, SAR_Max, ii) < iClose(NULL, p, ii))
           ii++;
       if(Error(p,ii+1) == 1) 
           return("Absent data");
       return("Buy("+DoubleToStr(ii,0)+")");
     } 
  }
//+------------------------------------------------------------------+
//| MACD                                                             |
//+------------------------------------------------------------------+
string MACD(int p)
  {
   int ii = 1;
   if(iMACD(NULL, p, Fast_EMA, Slow_EMA, MACD_SMA, PRICE_MEDIAN, 0, 0) < 
      iMACD(NULL, p, Fast_EMA, Slow_EMA, MACD_SMA, PRICE_MEDIAN, 1, 0))
     {
       while(iMACD(NULL, p, Fast_EMA, Slow_EMA, MACD_SMA, 
             PRICE_MEDIAN, 0, ii) < 
             iMACD(NULL, p, Fast_EMA, Slow_EMA, MACD_SMA, 
             PRICE_MEDIAN, 1, ii))
           ii++;
       if(Error(p, ii + 1) == 1) 
           return("Absent data");
       return("Sell(" + DoubleToStr(ii, 0) + ")");
     }
   else 
     {
       while(iMACD(NULL, p, Fast_EMA, Slow_EMA, MACD_SMA, 
             PRICE_MEDIAN, 0, ii) > 
             iMACD(NULL, p, Fast_EMA, Slow_EMA, MACD_SMA, 
             PRICE_MEDIAN, 1, ii))
           ii++;
       if(Error(p, ii + 1) == 1) 
           return("Absent data");
       return("Buy(" + DoubleToStr(ii, 0) + ")");
     }
  }
//+------------------------------------------------------------------+
//| Crossing MA                                                      |
//+------------------------------------------------------------------+
string CMA(int p)
  {
   int ii = 1;
   if(iMA(NULL, p, Fast_MA, 0, MODE_SMA, PRICE_MEDIAN, 0) < 
      iMA(NULL, p, Slow_MA, 0, MODE_SMA, PRICE_MEDIAN, 0))
     {
       while(iMA(NULL, p, Fast_MA, 0, MODE_SMA, PRICE_MEDIAN, ii) < 
             iMA(NULL, p, Slow_MA, 0, MODE_SMA, PRICE_MEDIAN, ii))
           ii++;
       if(Error(p, ii + 1) == 1) 
           return("Absent data");
       return("Sell(" + DoubleToStr(ii, 0) + ")");
     }
   else
     {
       while(iMA(NULL, p, Fast_MA, 0, MODE_SMA, PRICE_MEDIAN, ii) > 
             iMA(NULL, p, Slow_MA, 0, MODE_SMA, PRICE_MEDIAN, ii))
           ii++;
       if(Error(p, ii + 1) == 1) 
           return("Absent data");
       return("Buy(" + DoubleToStr(ii, 0) + ")");
     }
  }
//+------------------------------------------------------------------+
//| ADX                                                              |
//+------------------------------------------------------------------+
string ADX(int p)
  {
   int ii = 1;
   if(iADX(NULL, p, ADX_Period, PRICE_MEDIAN, 1, 0) < 
      iADX(NULL, p, ADX_Period, PRICE_MEDIAN, 2, 0))
     {
       while(iADX(NULL, p, ADX_Period, PRICE_MEDIAN, 1, ii) < 
             iADX(NULL, p, ADX_Period, PRICE_MEDIAN, 2, ii))
           ii++;
       if(Error(p, ii + 1) == 1) 
           return("Absent data");
       return("Sell(" + DoubleToStr(ii, 0) + ")");
     }
   else
     {
       while(iADX(NULL, p, ADX_Period, PRICE_MEDIAN, 1, ii) > 
             iADX(NULL, p, ADX_Period, PRICE_MEDIAN, 2, ii))
           ii++;
       if(Error(p,ii+1) == 1) 
           return("Absent data");
       return("Buy(" + DoubleToStr(ii, 0) + ")");
     }
  }
/*//+------------------------------------------------------------------+
//|  1                                                        |
//+------------------------------------------------------------------+
string (int p)
  {
   int ii = 1;
   if(   - true - sell, false - buy)
     {
       while(  sell)
           ii++;
       if(Error(p, ii + 1) == 1) 
           return("Absent data");
       return("Sell(" + DoubleToStr(ii, 0) + ")");
     }
   else
     {
       while(  buy)
           ii++;
       if(Error(p,ii+1) == 1) 
           return("Absent data");
       return("Buy(" + DoubleToStr(ii, 0) + ")");
     }
  }*/
/*//+------------------------------------------------------------------+
//|  2                                                        |
//+------------------------------------------------------------------+
string (int p)
  {
    int ii = 1;
    if(   - true - sell, false - buy)
      {
        while(  sell)
            ii++;
        if(Error(p, ii + 1) == 1) 
            return("Absent data");
        return("Sell(" + DoubleToStr(ii, 0) + ")");
      }
    else
      {
        while(  buy)
            ii++;
        if(Error(p, ii + 1) == 1) 
            return("Absent data");
        return("Buy(" + DoubleToStr(ii, 0) + ")");
      }
  }*/
/*//+------------------------------------------------------------------+
//|  3                                                        |
//+------------------------------------------------------------------+
string (int p)
  {
   int ii = 1;
   if(   - true - sell, false - buy)
     {
       while(  sell)
           ii++;
       if(Error(p, ii+ 1) == 1) 
           return("Absent data");
       return("Sell(" + DoubleToStr(ii, 0) + ")");
     }
   else
     {
       while(  buy)
           ii++;
       if(Error(p, ii + 1) == 1) 
           return("Absent data");
       return("Buy(" + DoubleToStr(ii, 0) + ")");
     }
  }*/
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
  {
//        
   a = WindowBarsPerChart(); 
   b = a - (0.3*a);
   t1 = Time[b];
   t2 = Time[0];
   for(int i = 1; i <= 5; i++)
     {
       if(i == 1)
         {
           b = a - (0.41*a);
           textT[i] = Time[b];
         }
       else
         {
           b = a - ((0.34 + (i*0.12))*a);
           textT[i] = Time[b];
         }
     }
   for(i = 0; i <= 7; i++)
       textC[i] = 9.5 - i;
   for(i = 1; i <= 4; i++)
     {
       if(i == 1)
         {
           b = a - (0.52*a);
           tt[i] = Time[b];
         }
       else
         {
           b = a - ((0.52 + (0.12*(i - 1)))*a);
           tt[i] = Time[b];
         }
     }
//------------ 
//  
   for(i = 1; i <= 7; i++)
     {
       ObjectDelete("1" + DoubleToStr(i, 0));
       ObjectCreate("1" + DoubleToStr(i, 0), OBJ_TEXT, 
                    WindowFind("Real_Time_MultiIndicator_v2"), 
                    textT[1], textC[i]);
       ObjectSetText("1" + DoubleToStr(i, 0), name[i-1], 13, 
                     "Tahoma", TxtColor);
     }
//------------    
//     
   for(i = 1; i <= 4; i++)
     {
       ObjectDelete("2" + DoubleToStr(i, 0));
       ObjectCreate("2" + DoubleToStr(i, 0), OBJ_TEXT, 
                    WindowFind("Real_Time_MultiIndicator_v2"), 
                    textT[i+1], textC[1]);
       ObjectSetText("2" + DoubleToStr(i, 0), SAR(per[i-1]), 13, 
                     "Tahoma", TxtColor);
     }
//     
   for(i = 1; i <= 4; i++)
     {
       ObjectDelete("3" + DoubleToStr(i, 0));
       ObjectCreate("3" + DoubleToStr(i, 0), OBJ_TEXT, 
                    WindowFind("Real_Time_MultiIndicator_v2"), 
                    textT[i+1], textC[2]);
       ObjectSetText("3" + DoubleToStr(i, 0), MACD(per[i-1]), 13, 
                     "Tahoma", TxtColor);
     }
//     
   for(i = 1; i <= 4; i++)
     {
       ObjectDelete("4" + DoubleToStr(i, 0));
       ObjectCreate("4" + DoubleToStr(i, 0), OBJ_TEXT, 
                    WindowFind("Real_Time_MultiIndicator_v2"), 
                    textT[i+1], textC[3]);
       ObjectSetText("4" + DoubleToStr(i, 0), CMA(per[i-1]), 13, 
                     "Tahoma", TxtColor);
     }
//     
   for(i = 1; i <= 4; i++)
     {
       ObjectDelete("5" + DoubleToStr(i, 0));
	      ObjectCreate("5" + DoubleToStr(i, 0), OBJ_TEXT, 
	                   WindowFind("Real_Time_MultiIndicator_v2"), 
	                   textT[i+1], textC[4]);
	      ObjectSetText("5" + DoubleToStr(i, 0), ADX(per[i-1]), 13, 
	                    "Tahoma", TxtColor);
	    }
/*//     
   for(i = 1; i <= 4; i++)
     {
       ObjectDelete("6" + DoubleToStr(i, 0));
	      ObjectCreate("6" + DoubleToStr(i, 0), OBJ_TEXT, 
	                   WindowFind("Real_Time_MultiIndicator_v2"), 
	                   textT[i+1], textC[5]);
	      ObjectSetText("6" + DoubleToStr(i, 0), (per[i-1]), 13, 
	                    "Tahoma", TxtColor);
	    }*/
/*//     
   for(i = 1; i <= 4; i++)
     {
       ObjectDelete("7" + DoubleToStr(i, 0));
	      ObjectCreate("7" + DoubleToStr(i, 0), OBJ_TEXT, 
	                   WindowFind("Real_Time_MultiIndicator_v2"), 
	                   textT[i+1], textC[6]);
	      ObjectSetText("7" + DoubleToStr(i, 0), (per[i-1]), 13, 
	                    "Tahoma", TxtColor);
	    }*/
/*//     
   for(i = 1; i <= 4; i++)
     {
       ObjectDelete("8" + DoubleToStr(i, 0));
	      ObjectCreate("8" + DoubleToStr(i, 0), OBJ_TEXT, 
	                   WindowFind("Real_Time_MultiIndicator_v2"), 
	                   textT[i+1], textC[7]);
	      ObjectSetText("8" + DoubleToStr(i, 0), (per[i-1]), 13, 
	                    "Tahoma", TxtColor);
	    }*/
//------------ 
//  
   for(i = 1; i <= 5; i++)
     {   	  
	      ObjectDelete(DoubleToStr(i, 0));
	      ObjectCreate(DoubleToStr(i, 0), OBJ_TEXT, 
	                   WindowFind("Real_Time_MultiIndicator_v2"), 
	                   textT[i], textC[0]);
	      ObjectSetText(DoubleToStr(i, 0), nameS[i-1], 13, "Tahoma",
	                    TxtColor);
	    }
//   
   for(i = 1; i <= 7; i++)	
	    {
       ObjectDelete("Tb" + DoubleToStr(i, 0));
       ObjectCreate("Tb" + DoubleToStr(i, 0), OBJ_RECTANGLE, 
                    WindowFind("Real_Time_MultiIndicator_v2"), 
                    t1, i, t2, 9.0);
       ObjectSet("Tb" + DoubleToStr(i, 0), OBJPROP_COLOR, TColor);
       ObjectSet("Tb" + DoubleToStr(i, 0), OBJPROP_BACK, false);
     }
//  
   ObjectDelete("Tbl8");
   ObjectCreate("Tbl8", OBJ_RECTANGLE, 
   WindowFind("Real_Time_MultiIndicator_v2"), 
                t1, 8.0, t2, 9.0);
   ObjectSet("Tbl8", OBJPROP_COLOR, TColor);
   ObjectSet("Tbl8", OBJPROP_BACK, true);
//     
   for(i = 1; i <= 4; i++)
     {
       ObjectDelete("Tb2" + DoubleToStr(i, 0));
       ObjectCreate("Tb2" + DoubleToStr(i, 0), OBJ_RECTANGLE, 
                    WindowFind("Real_Time_MultiIndicator_v2"), 
                    t1, 1.0, tt[i], 9.0);
       ObjectSet   ("Tb2" + DoubleToStr(i, 0), OBJPROP_COLOR, TColor);
       ObjectSet   ("Tb2" + DoubleToStr(i, 0), OBJPROP_BACK, false);
     }
//----                   
   return(0);
  }
//+------------------------------------------------------------------+